# This file is part of Tryton.  The COPYRIGHT file at the top level of
# this repository contains the full copyright notices and license terms.
from trytond.model import ModelView, ModelSQL, ModelSingleton, fields
from trytond.transaction import Transaction

__all__ = ['Configuration']


class Configuration(ModelSingleton, ModelSQL, ModelView):
    'CRM Configuration'
    __name__ = 'crm.configuration'
    crm_customer_service_sequence = fields.Many2One('ir.sequence',
        'Customer Service Sequence', required=True, domain=[
            ('code', '=', 'crm.customer_service')])
    crm_survey_sequence = fields.Many2One('ir.sequence',
        'Survey Sequence', required=True, domain=[
            ('code', '=', 'crm.customer_service')])
    efficay_hour_limit = fields.Integer('Efficay Hour Limit',
        required=True)
    crm_activity_sequence = fields.Many2One('ir.sequence',
        'Activity Sequence', required=True, domain=[
        ('code', '=', 'crm.customer_service')])
    company = fields.Many2One('company.company', 'Company', required=True)

    @staticmethod
    def default_company():
        return Transaction().context.get('company')

    @classmethod
    def get_configuration(cls):
        res = cls.search([
            ('company', '=', Transaction().context.get('company'))
        ])
        return res[0]
